# tikzpics

Python interface to generate (readable) Tikz figures.

Documentation: https://max-models.github.io/tikzpics/

# Install

Create and activate python environment

```
python -m venv env
source env/bin/activate
pip install --upgrade pip
```

Install the code and requirements with pip

```
pip install -e .
```

To install optional dependencies:

```
pip install -e ".[test]" # For pytest
pip install -e ".[dev]" For developers
```
